summaryrefslogtreecommitdiff
path: root/src/conf_mode/protocols_ospf.py
diff options
context:
space:
mode:
authorViacheslav Hletenko <v.gletenko@vyos.io>2026-06-17 14:21:35 +0300
committerGitHub <noreply@github.com>2026-06-17 14:21:35 +0300
commit7a1fa970b13c0006fa59ad9a46023b3e8037de6f (patch)
tree1e3b19c7162212f552b77297b03875d92daf33dd /src/conf_mode/protocols_ospf.py
parentc207f4a1ce9b13cd7e0664d35d805e633ebc69fb (diff)
parent040a4c0565081d0b6df2bf789737ed0e7bde2642 (diff)
downloadvyos-1x-7a1fa970b13c0006fa59ad9a46023b3e8037de6f.tar.gz
vyos-1x-7a1fa970b13c0006fa59ad9a46023b3e8037de6f.zip
Merge pull request #5277 from c-po/can-not-cannot
T8923: normalize "can not" to "cannot" and other typo fixes
Diffstat (limited to 'src/conf_mode/protocols_ospf.py')
-rwxr-xr-xsrc/conf_mode/protocols_ospf.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/conf_mode/protocols_ospf.py b/src/conf_mode/protocols_ospf.py
index b20cea25a..33eb4a762 100755
--- a/src/conf_mode/protocols_ospf.py
+++ b/src/conf_mode/protocols_ospf.py
@@ -90,19 +90,19 @@ def verify(config_dict):
if 'interface' in ospf:
for interface, interface_config in ospf['interface'].items():
verify_interface_exists(ospf, interface)
# One can not use dead-interval and hello-multiplier at the same
# time. FRR will only activate the last option set via CLI.
if {'hello_multiplier', 'dead_interval'} <= set(interface_config):
- raise ConfigError(f'Can not use hello-multiplier and dead-interval ' \
+ raise ConfigError(f'Cannot use hello-multiplier and dead-interval ' \
f'concurrently for {interface}!')
# One can not use the "network <prefix> area <id>" command and an
# per interface area assignment at the same time. FRR will error
# out using: "Please remove all network commands first."
if 'area' in ospf and 'area' in interface_config:
for area, area_config in ospf['area'].items():
if 'network' in area_config:
- raise ConfigError('Can not use OSPF "interface area" and ' \
+ raise ConfigError('Cannot use OSPF "interface area" and ' \
'"area network" configuration at the same time!')
# FRR only allows a single authentication mode (MD5, NULL or plaintext)
@@ -111,7 +111,7 @@ def verify(config_dict):
auth_keys = set(interface_config['authentication'])
exclusive_auth_keys = {'md5', 'null', 'plaintext_password'}
if len(auth_keys & exclusive_auth_keys) >= 2:
- raise ConfigError('Can not use multiple authentication modes '
+ raise ConfigError('Cannot use multiple authentication modes '
f'simultaneously for interface "{interface}"!')
# If interface specific options are set, we must ensure that the
@@ -192,7 +192,7 @@ def verify(config_dict):
if 'summary_address' in ospf:
for prefix, prefix_options in ospf['summary_address'].items():
if {'tag', 'no_advertise'} <= set(prefix_options):
- raise ConfigError(f'Can not set both "tag" and "no-advertise" for Type-5 '\
+ raise ConfigError(f'Cannot set both "tag" and "no-advertise" for Type-5 '\
f'and Type-7 route summarisation of "{prefix}"!')
return None
@@ -90,19 +90,19 @@ def verify(config_dict):
for interface, interface_config in ospf['interface'].items():
verify_interface_exists(ospf, interface)
- # One can not use dead-interval and hello-multiplier at the same
+ # One cannot use dead-interval and hello-multiplier at the same
# time. FRR will only activate the last option set via CLI.
if {'hello_multiplier', 'dead_interval'} <= set(interface_config):
@@ -90,19 +90,19 @@ def verify(config_dict):
f'concurrently for {interface}!')
- # One can not use the "network <prefix> area <id>" command and an
+ # One cannot use the "network <prefix> area <id>" command and an
# per interface area assignment at the same time. FRR will error
# out using: "Please remove all network commands first."